@@ -14,7 +14,7 @@ class Cfg:
     VIDEO_DIR           = ""
     CACHE_DIR_DEFAULT   = "mtube"+os.path.sep+".cache"
     CACHE_DIR           = ""
-    VER                 = "0.1.5-2"
+    VER                 = "0.1.5-3"
     CMD_MPLAYER_DEFAULT = "mplayer -osdlevel 3 -correct-pts -subfont-osd-scale 3 -- %s".split(" ")
     CMD_MPLAYER         = CMD_MPLAYER_DEFAULT
     CMD_YTDL_DEFAULT    = "youtube-dl-x -o %d -- %s".split(" ")
@@ -101,8 +101,13 @@ class Cfg:
                     (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
         else:
             import hildon
-            fc = hildon.FileChooserDialog(Cfg.__hiddenWindow, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
-        
+            try:
+                fc = hildon.FileChooserDialog(Cfg.__hiddenWindow, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
+            except:
+                #fremantle?
+                fc = hildon.FileChooserDialog(Cfg.__hiddenWindow, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                              hildon.FileSystemModel(root_dir="/"))
+                        
         fc.set_current_folder(Cfg.STORE_PATH)
         res = fc.run()
         fc.hide()
@@ -139,4 +144,4 @@ class Cfg:
                 gtk.rc_reparse_all_for_settings(rcCrt,True)
                 return
     
-    setGtkTheme = staticmethod(setGtkTheme)
\ No newline at end of file
+    setGtkTheme = staticmethod(setGtkTheme)
