@@ -852,7 +852,10 @@ class GuiMyTube:
         file_menu.append(menuitem)
         
         if mutils.isMaemo():
-            self.window.set_menu(file_menu)
+            try:
+                self.window.set_menu(file_menu)
+            except:
+                print "no set_menu: fremantle?"
             
     def showPrefs(self, ignore=None):
         #try to load code when needed only to speed up things
