@@ -125,12 +125,15 @@ def getTagNames():
     """returns all the available tags"""
     prefixLen = len(PREFIX)
     all = []
-    for fentry in os.listdir(Cfg.VIDEO_DIR):
-        fentry = fentry.strip()
-        #to be a valid record some files must be there
-        if not fentry.startswith(PREFIX):
-            continue
-        all.append(fentry[prefixLen:])
+    try:
+        for fentry in os.listdir(Cfg.VIDEO_DIR):
+            fentry = fentry.strip()
+            #to be a valid record some files must be there
+            if not fentry.startswith(PREFIX):
+                continue
+            all.append(fentry[prefixLen:])
+    except:
+        mutils.log("failed reading tags")
     return all
 
 #creats a new tag list
