@@ -664,14 +664,20 @@ class ScrollWidget(gtk.DrawingArea):
 
   def _apply_friction(self):      
     self.friction_c = self.friction_c + float(Cfg.KIN_FRIC)/100
+    slowed = False
     if self.friction_c >= self.friction:
-      self.friction_c = 0
-      self.speed = self.speed - cmp(self.speed,0)
-      
-    if abs(self.speed) < 1: # Special handling to snap to a sprite when we get slow
+        self.friction_c = 0
+        self.speed = self.speed - cmp(self.speed,0)
+        slowed = True
+    
+    snap_at = 2
+    
+    if abs(self.speed) <=snap_at: # Special handling to snap to a sprite when we get slow
         if abs(self.offset) > 5:
             # still have a ways to go, so don't slow down yet
-            self.speed = self.speed + cmp(self.speed,0)
+            #if slowed and abs(self.speed) < snap_at:
+            #    self.speed = self.speed + cmp(self.speed,0)
+            pass
         else:
             # Just snap to the edge
             self.speed = 0
@@ -688,7 +694,7 @@ class ScrollWidget(gtk.DrawingArea):
 
     self.offset = self.offset + self.speed
     self._calc_viewport_index()
-    if not self.speed: 
+    if not self.speed:
         return
     self._apply_friction()
 
